@@ -2,7 +2,7 @@ package Test2::Harness::Job::Runner::Open3;
 use strict;
 use warnings;
 
-our $VERSION = '0.001033';
+our $VERSION = '0.001034';
 
 use IPC::Open3 qw/open3/;
 use Test2::Harness::Util qw/open_file write_file local_env/;
@@ -11,7 +11,7 @@ use Carp qw/cluck/;
 
 use File::Spec();
 
-sub viable { cluck __PACKAGE__ . " is deprecated"; 1 }
+sub viable { 1 }
 
 sub find_inc {
     my $class = shift;
